@@ -1,4 +1,4 @@
-joint_test <- function(object, joint_index = NULL, hypothesis = 0, joint_test = "f", df = NULL) {
+joint_test <- function(object, joint_index = NULL, hypothesis = 0, joint_test = "f", df = NULL, vcov = TRUE) {
   checkmate::assert_choice(joint_test, c("f", "chisq"))
 
   if (joint_test == "f") {
@@ -32,7 +32,7 @@ joint_test <- function(object, joint_index = NULL, hypothesis = 0, joint_test =
   }
 
   # V_hat: estimated covariance matrix
-  V_hat <- stats::vcov(object)
+  V_hat <- get_vcov(object, vcov = vcov)
 
   # R: Q x P matrix for testing Q hypotheses on P parameters
   # build R matrix based on joint_index
@@ -69,26 +69,33 @@ joint_test <- function(object, joint_index = NULL, hypothesis = 0, joint_test =
 
   # Degrees of freedom
   if (is.null(df)) {
-    # n: sample size
-    n <- tryCatch(stats::nobs(object), error = function(e) NULL)
-    if (is.null(n)) n <- tryCatch(stats::nobs(attr(object, "model")), error = function(e) NULL)
-    if (is.null(n)) insight::format_error("Could not extract sample size from model object.")
-
-
-    if (inherits(object, "lme")) {
-      msg <- "The `hypotheses()` functions uses simple heuristics to select degrees of freedom for this test. See the relevant section in `?hypotheses`. These rules are likely to yield inappropriate results for models of class `%s`. Please supply degrees of freedom values explicitly via the `df` argument."
-      msg <- sprintf(msg, class(object)[1])
-      insight::format_warning(msg)
-    }
-
 
     df1 <- dim(R)[1] # Q
-    df2 <- tryCatch(insight::get_df(attr(object, "model")), error = function(e) NULL)
-    if (is.null(df2)) tryCatch(insight::get_df(object), error = function(e) NULL)
-    if (is.null(df2)) df2 <- n - length(theta_hat) # n - P
+
+    if (joint_test == "f") {
+      df2 <- tryCatch(insight::get_df(attr(object, "model")), error = function(e) NULL)
+      if (is.null(df2)) tryCatch(insight::get_df(object), error = function(e) NULL)
+      if (is.null(df2)) {
+        # n: sample size
+        n <- tryCatch(stats::nobs(object), error = function(e) NULL)
+        if (is.null(n)) n <- tryCatch(stats::nobs(attr(object, "model")), error = function(e) NULL)
+        if (is.null(n)) insight::format_error("Could not extract sample size from model object.")
+
+        if (inherits(object, "lme")) {
+          msg <- "The `hypotheses()` functions uses simple heuristics to select degrees of freedom for this test. See the relevant section in `?hypotheses`. These rules are likely to yield inappropriate results for models of class `%s`. Please supply degrees of freedom values explicitly via the `df` argument."
+          msg <- sprintf(msg, class(object)[1])
+          insight::format_warning(msg)
+        }
+
+        df2 <- n - length(theta_hat) # n - P
+      }
+    }
   } else {
     df1 <- df[1]
-    df2 <- df[2]
+
+    if (joint_test == "f") {
+      df2 <- df[2]
+    }
   }
 
   # Calculate the p-value
